! functions for plotting station data in GNUplot

module gnuplotstations_lo
    use ecrlib, only: gnuplot2Dplotcolumn
    use outstations, only: numstations, stationnames 

contains

! writes out an extended plot command to plot data from all the stations on the
! same plot (minus the opening "plot" command)
!   datafile       The data file to plot from (written using ecrlib's
!                  gnuplot2Ddata subroutine)
!   suffix         extra stuff to put after the file name to control plotting
!   lun            logical unit to write to
subroutine gnuplot2Dplotstations(datafile, suffix, lun)
character(len=*), intent(in) :: datafile, suffix
integer, intent(in) :: lun

character (len=50) :: options
integer :: ia ! stations counter
do ia = 1, numstations
  ! build up the options for this line
  write(options, '(a,a,a,i2,a,a)') 'title "', stationnames(ia), '" ls ', ia, &
    ' ', suffix
  ! write out line
  call gnuplot2Dplotcolumn(ia, datafile, options, lun)
  if (ia .lt. numstations) then
    ! I really wish you could do this without a newline
    write(lun, '(a)') ', \'
  end if
end do
end subroutine gnuplot2Dplotstations

! set up some sensible line styles to belong to the 6 stations
!   lun     logical unit to write to
subroutine gnuplot2Dstationlines(lun)
integer, intent(in) :: lun

write(lun, '(a)') 'set style line 1 lt 1 lc rgb "red" pt "circles" ps "0.5"'
write(lun, '(a)') 'set style line 2 lt 1 lc rgb "blue" pt "circles" ps "0.5"'
write(lun, '(a)') 'set style line 3 lt 1 lc rgb "green" pt "circles" ps "0.5"'
write(lun, '(a)') 'set style line 4 lt 1 lc rgb "magenta" pt "circles" ps "0.5"'
write(lun, '(a)') 'set style line 5 lt 1 lc rgb "dark-green" pt "circles" ps "0.5"'
write(lun, '(a)') 'set style line 6 lt 1 lc rgb "dark-yellow" pt "circles" ps "0.5"'

end subroutine gnuplot2Dstationlines
end module gnuplotstations_lo
